# frozen_string_literal: true

require_dependency 'webhooks/application_controller'

module Webhooks
  class EndpointsController < ApplicationController
    def index
      @endpoints = Webhooks::Endpoint.order(created_at: :asc)
    end

    def show
      @endpoint = Webhooks::Endpoint.find(params[:id])
    end

    def new
      @endpoint = Webhooks::Endpoint.new
    end

    def create
      @endpoint = Webhooks::Endpoint.new(endpoint_params)

      if @endpoint.save
        redirect_to endpoint_path(@endpoint), flash: {
          success: 'Successfully created new webhook endpoint.',
        }
      else
        render :new
      end
    end

    def edit
      @endpoint = Webhooks::Endpoint.find(params[:id])
    end

    def update
      @endpoint = Webhooks::Endpoint.find(params[:id])

      if @endpoint.update(endpoint_params)
        redirect_to edit_endpoint_path(@endpoint), flash: {
          success: 'Changes saved.',
        }
      else
        render :edit
      end
    end

    def destroy
      @endpoint = Webhooks::Endpoint.find(params[:id])

      if @endpoint.destroy
        redirect_to endpoints_path, flash: {
          success: 'Deleted endpoint.',
        }
      else
        redirect_back fallback_location: @endpoint
      end
    end

    private

    def endpoint_params
      params.require(:endpoint).permit(:url, event_types: [])
    end
  end
end
