# frozen_string_literal: true

module Webhooks
  class Event < ApplicationRecord
    validates :event_type,
      presence: true,
      inclusion: {
        in: Rails.application.config.webhooks.events.types,
      }

    validates :event,
      presence: true,
      length: {
        minimum: 1,
      }

    has_many :attempts,
      foreign_key: :webhooks_event_id,
      inverse_of: :event,
      dependent: :destroy

    has_many :endpoints, through: :attempts
    before_validation :enforce_create_without_subscribed_endpoint_setting

    after_create :create_attempts

    def to_s
      event_type
    end

    private

    def subscribed_endpoint_scope
      Endpoint.subscribed(event_type)
    end

    def enforce_create_without_subscribed_endpoint_setting
      return if Rails.application.config.webhooks.events.create_without_subscribed_endpoint
      return if subscribed_endpoint_scope.any?

      errors.add(:base, :no_endpoints_subscribed)
    end

    def create_attempts
      subscribed_endpoint_scope.find_each do |endpoint|
        attempts.create!(endpoint: endpoint)
      end
    end
  end
end
