# frozen_string_literal: true

module Webhooks
  class Request < ApplicationRecord
    belongs_to :attempt, class_name: 'Webhooks::Attempt', foreign_key: :webhooks_attempt_id, inverse_of: :request
    has_one :response, class_name: 'Webhooks::Response', foreign_key: :webhooks_request_id, inverse_of: :request, dependent: :destroy

    # Delegated associations
    has_one :endpoint, through: :attempt
    has_one :event, through: :attempt

    before_create :perform_request
    after_create :record_response

    private

    def perform_request
      self.body ||= EventSerializer.new(self).to_json

      @response = Webhooks.client.post(endpoint.url) do |req|
        timestamp = Time.zone.now
        timestamped_payload = "#{timestamp.to_i}.#{body}"
        signature = OpenSSL::HMAC.hexdigest(OpenSSL::Digest.new('sha256'), endpoint.secret, timestamped_payload)

        req.headers[Rails.application.config.webhooks.requests.header] = "t=#{timestamp.to_i},v1=#{signature}"

        req.body = body
      end

      self.headers = @response.env.request_headers
    end

    def record_response
      create_response!(response: @response)
    end
  end
end
