# frozen_string_literal: true

module Webhooks
  class Response < ApplicationRecord
    belongs_to :request, class_name: 'Webhooks::Request', foreign_key: :webhooks_request_id, inverse_of: :response
    has_one :attempt, through: :request
    has_one :endpoint, through: :attempt

    validates :status_code, presence: true
    validates :headers, presence: true

    after_create :update_attempt_state

    def update_attempt_state
      case status_code
      when 200..299
        attempt.update!(state: :success)
      else
        attempt.update!(state: :error)
      end
    end

    def response=(response)
      self.status_code = response.status
      self.headers = response.headers
      self.body = response.body
    end
  end
end
