# frozen_string_literal: true

class CreateWebhooksAttempts < ActiveRecord::Migration[6.1]
  def change
    reversible do |direction|
      direction.up do
        execute <<-SQL.squish
          DROP INDEX IF EXISTS index_webhooks_attempts_on_endpoint_id_and_event_id_and_attempt;
        SQL
      end
    end

    create_table :webhooks_attempts do |t|
      t.belongs_to :webhooks_endpoint, null: false, foreign_key: true
      t.belongs_to :webhooks_event, null: false, foreign_key: true

      # Was this attempt triggered manually?
      t.boolean :manual, null: false, default: false
      t.integer :state, null: false, default: 0
      t.integer :attempt, null: false, default: 1

      t.datetime :retry_at, null: true, precision: 6
      t.timestamps null: false, precision: 6

      t.index %i[webhooks_endpoint_id webhooks_event_id attempt], unique: true, name: 'index_webhooks_attempts_on_endpoint_id_and_event_id_and_attempt'
    end

    reversible do |direction|
      direction.up do
        execute <<-SQL.squish
          CREATE UNIQUE INDEX index_webhooks_attempts_on_endpoint_id_and_event_id_and_attempt ON webhooks_attempts ("webhooks_endpoint_id", "webhooks_event_id", "attempt") WHERE "manual" = 'f';
        SQL
      end
    end
  end
end
