# frozen_string_literal: true

module Webhooks
  class Engine < ::Rails::Engine
    isolate_namespace Webhooks

    engine_name 'webhooks'

    config.webhooks = ActiveSupport::OrderedOptions.new
    config.webhooks.events = ActiveSupport::OrderedOptions.new

    # If there are no webhook endpoints subscribing to an event that was just
    # published, decide if we want to store the event or not. Storing the event
    # will not trigger any webhook attempts at that time or in the future.
    config.webhooks.events.create_without_subscribed_endpoint = false
    config.webhooks.events.types = []
    config.webhooks.user_agent = "webhooks-rails/v#{Webhooks::VERSION}"
    config.webhooks.endpoints = ActiveSupport::OrderedOptions.new
    config.webhooks.endpoints.valid_schemas = %w[https]

    # Configuration for the webhook attempts
    config.webhooks.attempts = ActiveSupport::OrderedOptions.new
    config.webhooks.attempts.limit = 3

    # Configuration for the actual webhook requests
    config.webhooks.requests = ActiveSupport::OrderedOptions.new
    config.webhooks.requests.read_timeout = 30
    config.webhooks.requests.open_timeout = 10
    config.webhooks.requests.header = 'X-Webhooks-Signature'
  end
end
